@@ -10,6 +10,7 @@ from nxt_editor.dockwidgets.dock_widget_base import DockWidgetBase
 from nxt import nxt_path
 from nxt_editor.dockwidgets.layer_manager import LetterCheckboxDelegeate
 import nxt_editor
+from nxt_editor import colors
 
 logger = logging.getLogger(nxt_editor.LOGGER_NAME)
 
@@ -320,7 +321,11 @@ class BuildTable(QtWidgets.QTableView):
         self.break_delegate = LetterCheckboxDelegeate('B')
         self.setItemDelegateForColumn(BuildModel.BREAK_COLUMN,
                                       self.break_delegate)
+        self.skip_delegate = LetterCheckboxDelegeate('S')
+        self.setItemDelegateForColumn(BuildModel.SKIP_COLUMN,
+                                      self.skip_delegate)
         self.clicked.connect(self.on_row_clicked)
+        # TODO context menu and shift-click for +descendents.
 
     def on_row_clicked(self, clicked_idx):
         """When a row in the table is clicked, select and frame.
@@ -349,7 +354,7 @@ class BuildTable(QtWidgets.QTableView):
 
     def on_build_idx_changed(self, build_idx):
         if self.model().stage_model.can_build_run():
-            model_index = self.model().index(build_idx + 1, 0)
+            model_index = self.model().index(build_idx, 0)
         else:
             model_index = self.model().index(0, 0)
         self.scrollTo(model_index, self.ScrollHint.PositionAtCenter)
@@ -359,19 +364,21 @@ class BuildModel(QtCore.QAbstractTableModel):
     """A model of a series of nodes that reflects execution information
     including break status, start status, and which node is next to be run.
     """
-    BREAK_COLUMN = 0
-    START_COLUMN = 1
-    PATH_COLUMN = 2
-    NEXT_RUN_COLUMN = 3
+    SKIP_COLUMN = 0
+    BREAK_COLUMN = 1
+    START_COLUMN = 2
+    PATH_COLUMN = 3
+    NEXT_RUN_COLUMN = 4
 
     def __init__(self, stage_model):
         super(BuildModel, self).__init__()
         """self._nodes is the execute order this build model with reflect
         answers about.
         """
-        self.headers = ['Break', 'Start', 'Path', 'Next']
+        self.headers = ['Skip', 'Break', 'Start', 'Path', 'Next']
         self.stage_model = stage_model
         self._nodes = []
+        self.stage_model.skips_changed.connect(self.on_skips_changed)
         self.stage_model.breaks_changed.connect(self.on_breaks_changed)
         self.stage_model.build_idx_changed.connect(self.on_build_idx_changed)
 
@@ -389,6 +396,11 @@ class BuildModel(QtCore.QAbstractTableModel):
         self._nodes = val
         self.endResetModel()
 
+    def on_skips_changed(self, new_skips):
+        last_row = len(self.nodes) - 1
+        self.dataChanged.emit(self.index(0, self.SKIP_COLUMN),
+                              self.index(last_row, self.SKIP_COLUMN))
+
     def on_breaks_changed(self, new_breaks):
         last_row = len(self.nodes) - 1
         self.dataChanged.emit(self.index(0, self.BREAK_COLUMN),
@@ -412,7 +424,7 @@ class BuildModel(QtCore.QAbstractTableModel):
         return len(self.nodes)
 
     def columnCount(self, index):
-        return 4
+        return len(self.headers)
 
     def data(self, index, role=None):
         row = index.row()
@@ -423,23 +435,28 @@ class BuildModel(QtCore.QAbstractTableModel):
                 return idx_path
         next_run = False
         if self.stage_model.is_build_setup():
-            next_run = row == self.stage_model.last_built_idx + 1
+            next_run = row == self.stage_model.last_built_idx
         elif row == 0:
             next_run = True
         is_start = self.stage_model.get_is_node_start(idx_path)
         is_break = self.stage_model.get_is_node_breakpoint(idx_path)
+        is_skip = self.stage_model.is_node_skippoint(idx_path)
         if role == QtCore.Qt.CheckStateRole:
             if column == self.START_COLUMN:
                 return QtCore.Qt.Checked if is_start else QtCore.Qt.Unchecked
             if column == self.BREAK_COLUMN:
                 return QtCore.Qt.Checked if is_break else QtCore.Qt.Unchecked
+            if column == self.SKIP_COLUMN:
+                return QtCore.Qt.Checked if is_skip else QtCore.Qt.Unchecked
             if column == self.NEXT_RUN_COLUMN:
                 return QtCore.Qt.Checked if next_run else QtCore.Qt.Unchecked
         if role == QtCore.Qt.BackgroundRole:
             if column == self.BREAK_COLUMN and is_break:
-                return QtGui.QBrush(QtCore.Qt.red)
+                return colors.BREAK_COLOR
+            if column == self.SKIP_COLUMN and is_skip:
+                return colors.SKIP_COLOR
             if column == self.START_COLUMN and is_start:
-                return QtGui.QBrush(QtCore.Qt.green)
+                return colors.START_COLOR
             if column == self.PATH_COLUMN and next_run:
                 return QtGui.QBrush(QtCore.Qt.red)
         if role == QtCore.Qt.ForegroundRole:
@@ -448,11 +465,18 @@ class BuildModel(QtCore.QAbstractTableModel):
 
     def setData(self, index, value, role=QtCore.Qt.EditRole):
         column = index.column()
-        if column != self.BREAK_COLUMN:
-            return False
         if role != QtCore.Qt.CheckStateRole:
             return False
         path = self.nodes[index.row()]
-        current_break = self.stage_model.get_is_node_breakpoint(path)
-        self.stage_model.set_breakpoints([path], not current_break)
-        return True
+        if column == self.BREAK_COLUMN:
+            current_break = self.stage_model.get_is_node_breakpoint(path)
+            self.stage_model.set_breakpoints([path], not current_break)
+            return True
+        if column == self.SKIP_COLUMN:
+            modifiers = QtWidgets.QApplication.keyboardModifiers()
+            if modifiers == QtCore.Qt.ShiftModifier:
+                self.stage_model.toggle_descendant_skips([path])
+            else:
+                self.stage_model.toggle_skippoints([path])
+            return True
+        return False
