@@ -17,6 +17,7 @@ from nxt_editor.node_graphics_item import (NodeGraphicsItem, NodeGraphicsPlug,
 from nxt_editor.connection_graphics_item import AttrConnectionGraphic
 from nxt_editor.dialogs import NxtWarningDialog
 from nxt_editor.commands import *
+from nxt_editor import colors
 from .user_dir import USER_PREF, user_prefs
 
 logger = logging.getLogger(nxt_editor.LOGGER_NAME)
@@ -121,7 +122,7 @@ class StageView(QtWidgets.QGraphicsView):
         self.prev_build_focus_path = None
 
         # local attributes
-        self.show_grid = True
+        self.show_grid = user_prefs.get(USER_PREF.SHOW_GRID, True)
         # connection attribute used when drawing connections
         self.potential_connection = None
 
@@ -137,7 +138,6 @@ class StageView(QtWidgets.QGraphicsView):
         self.model.node_moved.connect(self.handle_node_move)
         self.model.selection_changed.connect(self.on_model_selection_changed)
         self.model.frame_items.connect(self.frame_nodes)
-        self.model.build_idx_changed.connect(self.on_build_idx_changed)
         self.model.collapse_changed.connect(self.handle_collapse_changed)
 
         # initialize the view
@@ -298,7 +298,6 @@ class StageView(QtWidgets.QGraphicsView):
             self.show_grid = not self.show_grid
         else:
             self.show_grid = state
-        self.model.show_grid = self.show_grid
         self.update()
 
     def frame_all(self):
@@ -596,8 +595,7 @@ class StageView(QtWidgets.QGraphicsView):
         super(StageView, self).drawBackground(painter, rect)
 
         rect = self.sceneRect()
-        color = QtGui.QColor(35, 35, 35)
-        painter.fillRect(rect, QtGui.QBrush(color))
+        painter.fillRect(rect, QtGui.QBrush(colors.GRAPH_BG_COLOR))
 
         left = int(rect.left()) - (int(rect.left()) % self.draw_grid_size)
         top = int(rect.top()) - (int(rect.top()) % self.draw_grid_size)
@@ -914,7 +912,7 @@ class StageView(QtWidgets.QGraphicsView):
             items_released_on = self.items(event.pos())
             # using the 1 index item here because the 0 index thing will always be the connection
             if len(items_released_on) > 1:
-                if type(items_released_on[1]) is NodeGraphicsPlug:
+                if isinstance(items_released_on[1], NodeGraphicsPlug):
                     dropped_plug = items_released_on[1]
                     dropped_node_path = dropped_plug.parentItem().node_path
                     locked = self.model.get_node_locked(dropped_node_path)
@@ -1127,21 +1125,6 @@ class StageView(QtWidgets.QGraphicsView):
         #     return graphic.tgt_path
         return None
 
-    def on_build_idx_changed(self, build_idx):
-        prev_graphic = self.get_node_graphic(self.prev_build_focus_path)
-        if prev_graphic is not None:
-            prev_graphic.update_build_focus()
-        focus_path = self.model.get_build_focus()
-        if not focus_path:
-            self.prev_build_focus_path = None
-            return
-        graphic = self.get_node_graphic(focus_path)
-        if not graphic:
-            self.prev_build_focus_path = None
-            return
-        self.prev_build_focus_path = focus_path
-        graphic.update_build_focus()
-
     def on_model_selection_changed(self, new_selection):
         if not new_selection:
             self.scene().clearSelection()
